"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = transformPicker;
const transforms_1 = require("../../shared/transforms");
/**
 * Transforms Picker:
 * - Change menuWidth value from a DimensionValue to a pixel value.
 * - Remove isQuiet (it is no longer supported in Spectrum 2).
 * - Change validationState="invalid" to isInvalid.
 * - Remove validationState="valid" (it is no longer supported in Spectrum 2).
 * - Replace isLoading with loadingState.
 */
function transformPicker(path) {
    // Change menuWidth value from a DimensionValue to a pixel value
    (0, transforms_1.convertDimensionValueToPx)(path, { propName: 'menuWidth' });
    // Remove isQuiet
    (0, transforms_1.removeProp)(path, { propName: 'isQuiet' });
    // Change validationState="invalid" to isInvalid
    (0, transforms_1.updatePropNameAndValue)(path, {
        oldPropName: 'validationState',
        oldPropValue: 'invalid',
        newPropName: 'isInvalid',
        newPropValue: true
    });
    // Remove validationState="valid"
    (0, transforms_1.removeProp)(path, { propName: 'validationState', propValue: 'valid' });
    // Replace isLoading with loadingState
    (0, transforms_1.updatePropName)(path, {
        oldPropName: 'isLoading',
        newPropName: 'loadingState',
        comment: 'Replace boolean passed to isLoading with appropriate loadingState.'
    });
}
